.. _decoding_ref:

:mod:`nilearn.decoding`: Decoding
=================================

.. automodule:: nilearn.decoding
   :no-members:
   :no-inherited-members:

Classes
-------

.. currentmodule:: nilearn.decoding

.. autosummary::
   :toctree: generated/
   :template: class.rst

   Decoder
   DecoderRegressor
   FREMClassifier
   FREMRegressor
   SpaceNetClassifier
   SpaceNetRegressor
   SearchLight

.. autoclasstree:: nilearn.decoding
   :full:
